@@ -22,8 +22,6 @@
 
 (** Decode mpeg audio files using libmad. *)
 
-open Dtools
-
 let log = Log.make ["decoder";"mad"]
 
 let init input =
@@ -87,6 +85,9 @@ let init input =
           in
           ignore((Utils.get_some input.Decoder.lseek) seek_pos);
           dec := Mad.openstream input.Decoder.read;
+          (* Decode one frame to set the decoder to a good reading position
+           * on next read. *)
+          ignore(Mad.decode_frame_float !dec);
           (* We have to assume here that new_pos = seek_pos.. *)
           time_offset := seek_time
         with _ -> ()
@@ -136,12 +137,12 @@ module D = Make(G)
 
 (** Configuration keys for mad. *)
 let mime_types =
-  Conf.list ~p:(Decoder.conf_mime_types#plug "mad")
+  Dtools.Conf.list ~p:(Decoder.conf_mime_types#plug "mad")
     "Mime-types used for guessing mpeg audio format"
     ~d:["audio/mpeg"; "audio/MPA"]
 
 let file_extensions =
-  Conf.list ~p:(Decoder.conf_file_extensions#plug "mad")
+  Dtools.Conf.list ~p:(Decoder.conf_file_extensions#plug "mad")
     "File extensions used for guessing mpeg audio format"
     ~d:["mp3"; "mp2"; "mp1"]
 
@@ -177,7 +178,7 @@ let get_type filename =
                | Mad.Layer_II  -> "II"
                | Mad.Layer_III -> "III"
            in
-           log#f 4
+           log#info
              "Libmad recognizes %S as mpeg audio \
               (layer %s, %ikbps, %dHz, %d channels)."
              filename
@@ -210,7 +211,7 @@ let () =
           kind.Frame.audio = Frame.Succ Frame.Variable ||
           (* libmad always respects the first two kinds *)
           if Frame.type_has_kind (get_type filename) kind then true else begin
-             log#f 3
+             log#important
                "File %S has an incompatible number of channels."
                filename ;
              false
