@@ -20,17 +20,14 @@
 
  *****************************************************************************)
 
-type t =
-  {
-    (* Samplerate is lazy in order to avoid forcing the evaluation of the
-       samplerate at typing time, see #933. For channels this is pointless since
-       we really need that for typing. *)
-    samplerate : int Lazy.t;
-    channels : int;
-  }
+type t = {
+  (* Samplerate is lazy in order to avoid forcing the evaluation of the
+     samplerate at typing time, see #933. For channels this is pointless since
+     we really need that for typing. *)
+  samplerate : int Lazy.t;
+  channels : int;
+}
 
 let to_string w =
   let samplerate = Lazy.force w.samplerate in
-  Printf.sprintf
-    "%%avi(samplerate=%d,channels=%d)"
-    samplerate w.channels
+  Printf.sprintf "%%avi(samplerate=%d,channels=%d)" samplerate w.channels
