@@ -20,49 +20,34 @@
 
  *****************************************************************************)
 
-type application = [
-  | `Voip
-  | `Audio
-  | `Restricted_lowdelay
-]
-
-type bitrate = [
-  | `Auto
-  | `Bitrate_max
-  | `Bitrate of int
-]
+type application = [ `Voip | `Audio | `Restricted_lowdelay ]
+type bitrate = [ `Auto | `Bitrate_max | `Bitrate of int ]
 
 type mode =
-  | VBR of bool        (* Variable bitrate, constrained or not. *)
-  | CBR                (* Constant bitrate. *)
+  | VBR of bool
+  (* Variable bitrate, constrained or not. *)
+  | CBR
 
-type max_bandwidth = [
-  | `Narrow_band
-  | `Medium_band
-  | `Wide_band
-  | `Super_wide_band
-  | `Full_band
-]
+(* Constant bitrate. *)
 
-type signal = [
-  | `Auto
-  | `Voice
-  | `Music
-]
+type max_bandwidth =
+  [ `Narrow_band | `Medium_band | `Wide_band | `Super_wide_band | `Full_band ]
+
+type signal = [ `Auto | `Voice | `Music ]
 
 type t = {
-  application     : application option ;
-  bitrate         : bitrate ;
-  complexity      : int option ;
-  channels        : int ;
-  frame_size      : float ;
-  max_bandwidth   : max_bandwidth option ;
-  mode            : mode ;
-  samplerate      : int ;
-  signal          : signal option ;
-  fill            : int option ;
-  dtx             : bool ;
-  phase_inversion : bool
+  application : application option;
+  bitrate : bitrate;
+  complexity : int option;
+  channels : int;
+  frame_size : float;
+  max_bandwidth : max_bandwidth option;
+  mode : mode;
+  samplerate : int;
+  signal : signal option;
+  fill : int option;
+  dtx : bool;
+  phase_inversion : bool;
 }
 
 let string_of_bitrate = function
@@ -71,12 +56,13 @@ let string_of_bitrate = function
   | `Bitrate b -> Printf.sprintf "bitrate=%d," b
 
 let string_of_mode = function
-  | CBR   -> "vbr=\"none\""
-  | VBR b -> Printf.sprintf "vbr=%S" (if b then "constrained" else "unconstrained")
+  | CBR -> "vbr=\"none\""
+  | VBR b ->
+      Printf.sprintf "vbr=%S" (if b then "constrained" else "unconstrained")
 
 let string_of_application = function
   | None -> ""
-  | Some `Voip  -> "application=\"voip\","
+  | Some `Voip -> "application=\"voip\","
   | Some `Audio -> "application=\"audio\","
   | Some `Restricted_lowdelay -> "application=\"restricted_lowdelay\","
 
@@ -84,7 +70,7 @@ let string_of_bandwidth = function
   | None -> ""
   | Some `Narrow_band -> "max_bandwidth=\"narrow_band\","
   | Some `Medium_band -> "max_bandwidth=\"medium_band\","
-  | Some `Wide_band   -> "max_bandwidth=\"wide_band\","
+  | Some `Wide_band -> "max_bandwidth=\"wide_band\","
   | Some `Super_wide_band -> "max_bandwidth=\"super_wide_band\","
   | Some `Full_band -> "max_bandwidth=\"full_band\","
 
@@ -96,15 +82,14 @@ let string_of_signal = function
 
 let to_string v =
   Printf.sprintf
-  "%%opus(%s,%schannels=%d,%s%s%s%ssamplerate=%d,frame_size=%.02f,dtx=%B,phase_inversion=%b)"
+    "%%opus(%s,%schannels=%d,%s%s%s%ssamplerate=%d,frame_size=%.02f,dtx=%B,phase_inversion=%b)"
     (string_of_mode v.mode)
     (string_of_bitrate v.bitrate)
     v.channels
     (string_of_application v.application)
-    (match v.complexity with None -> "" | Some i -> (Printf.sprintf "complexity=\"%d\"," i))
+    ( match v.complexity with
+      | None -> ""
+      | Some i -> Printf.sprintf "complexity=\"%d\"," i )
     (string_of_bandwidth v.max_bandwidth)
     (string_of_signal v.signal)
-    v.samplerate
-    v.frame_size
-    v.dtx
-    v.phase_inversion
+    v.samplerate v.frame_size v.dtx v.phase_inversion
