@@ -20,17 +20,10 @@
 
  *****************************************************************************)
 
-type t = {
-  channels   : int ;
-  samplerate : int Lazy.t ;
-  bitrate    : int ;
-}
+type t = { channels : int; samplerate : int Lazy.t; bitrate : int }
 
 let to_string m =
-  Printf.sprintf "%%shine(channels=%d,samplerate=%d,bitrate=%d)"
-    m.channels
-    (Lazy.force m.samplerate)
-    m.bitrate
+  Printf.sprintf "%%shine(channels=%d,samplerate=%d,bitrate=%d)" m.channels
+    (Lazy.force m.samplerate) m.bitrate
 
-let bitrate m =
-  m.bitrate * 1000
+let bitrate m = m.bitrate * 1000
