@@ -288,10 +288,8 @@ class input ~kind ~bind_address ~max ~payload_size ~clock_safe ~on_connect
           self#log#debug "Failed to connect: %s." (Printexc.to_string exn);
           self#connect
       in
-      if not self#should_stop then begin
-        self#close_socket;
+      if not self#should_stop then
         Poll.add_socket ~mode:`Read self#get_socket on_connect
-      end
 
     method private get_frame frame =
       let pos = Frame.position frame in
