@@ -271,7 +271,7 @@ let is_source t =
 
 exception Unused_variable of (string * Lexing.position)
 
-let check_unused ~lib tm =
+let check_unused ~throw ~lib tm =
   let rec check ?(toplevel = false) v tm =
     match tm.term with
       | Var s -> Vars.remove s v
@@ -332,7 +332,7 @@ let check_unused ~lib tm =
                     && not (can_ignore def.t || (toplevel && is_fun def.t))
                   then (
                     let start_pos = fst (Utils.get_some tm.t.T.pos) in
-                    raise (Unused_variable (s, start_pos)) ))
+                    throw (Unused_variable (s, start_pos)) ))
               fvpat;
           Vars.union v mask
   in
@@ -586,7 +586,7 @@ let rec type_of_pat ~level ~pos = function
  * [level] should be the sum of the lengths of [env] and [builtins],
  * that is the size of the typing context, that is the number of surrounding
  * abstractions. *)
-let rec check ?(print_toplevel = false) ~level ~env e =
+let rec check ?(print_toplevel = false) ~throw ~level ~env e =
   (* The role of this function is not only to type-check but also to assign
    * meaningful levels to type variables, and unify the types of
    * all occurrences of the same variable, since the parser does not do it. *)
@@ -600,7 +600,7 @@ let rec check ?(print_toplevel = false) ~level ~env e =
   let mk t = T.make ~level ~pos t in
   let mkg t = mk (T.Ground t) in
   let check_fun ~proto ~env e body =
-    let base_check = check ~level ~env in
+    let base_check = check ~throw ~level ~env in
     let proto_t, env, level =
       List.fold_left
         (fun (p, env, level) -> function
@@ -621,7 +621,7 @@ let rec check ?(print_toplevel = false) ~level ~env e =
         ([], env, level) proto
     in
     let proto_t = List.rev proto_t in
-    check ~level ~env body;
+    check ~throw ~level ~env body;
     e.t >: mk (T.Arrow (proto_t, body.t))
   in
   match e.term with
@@ -631,7 +631,7 @@ let rec check ?(print_toplevel = false) ~level ~env e =
     | Float _ -> e.t >: mkg T.Float
     | Encoder f -> e.t >: type_of_format ~pos:e.t.T.pos ~level f
     | List l ->
-        List.iter (fun x -> check ~level ~env x) l;
+        List.iter (fun x -> check ~throw ~level ~env x) l;
         (* We first try to compute the sup of types of elements in the list,
            which will give us the type of the list. *)
         let tsup =
@@ -651,27 +651,27 @@ let rec check ?(print_toplevel = false) ~level ~env e =
         e.t >: mk (T.List tsup);
         List.iter (fun item -> item.t <: tsup) l
     | Tuple l ->
-        List.iter (fun a -> check ~level ~env a) l;
+        List.iter (fun a -> check ~throw ~level ~env a) l;
         e.t >: mk (T.Tuple (List.map (fun a -> a.t) l))
     | Ref a ->
-        check ~level ~env a;
+        check ~throw ~level ~env a;
         e.t >: ref_t ~pos ~level a.t
     | Get a ->
-        check ~level ~env a;
+        check ~throw ~level ~env a;
         a.t <: ref_t ~pos ~level e.t
     | Set (a, b) ->
-        check ~level ~env a;
-        check ~level ~env b;
+        check ~throw ~level ~env a;
+        check ~throw ~level ~env b;
         a.t <: ref_t ~pos ~level b.t;
         e.t >: mk T.unit
     | Seq (a, b) ->
-        check ~env ~level a;
-        if not (can_ignore a.t) then raise (Ignored a);
-        check ~print_toplevel ~level ~env b;
+        check ~throw ~env ~level a;
+        if not (can_ignore a.t) then throw (Ignored a);
+        check ~throw ~print_toplevel ~level ~env b;
         e.t >: b.t
     | App (a, l) -> (
-        check ~level ~env a;
-        List.iter (fun (_, b) -> check ~env ~level b) l;
+        check ~throw ~level ~env a;
+        List.iter (fun (_, b) -> check ~throw ~env ~level b) l;
         (* If [a] is known to have a function type, manually dig through
          * it for better error messages. Otherwise generate its type
          * and unify -- in that case the optionality can't be guessed
@@ -733,7 +733,7 @@ let rec check ?(print_toplevel = false) ~level ~env e =
           Printf.eprintf "Instantiate %s[%d] : %s becomes %s\n" var
             (T.deref e.t).T.level (T.print orig) (T.print e.t)
     | Let ({ pat; def; body; _ } as l) ->
-        check ~level ~env def;
+        check ~throw ~level ~env def;
         let generalized =
           if value_restriction def then (
             let f gen x t =
@@ -765,17 +765,17 @@ let rec check ?(print_toplevel = false) ~level ~env e =
                  if l >= max then name else name ^ String.make (max - l) ' ')
                 (T.pp_type_generalized generalized)
                 def.t);
-        check ~print_toplevel ~level:(level + 1) ~env body;
+        check ~throw ~print_toplevel ~level:(level + 1) ~env body;
         e.t >: body.t
 
 (* The simple definition for external use. *)
-let check ?(ignored = false) e =
+let check ?(ignored = false) ~throw e =
   let print_toplevel = !Configure.display_types in
   try
-    check ~print_toplevel ~level:(List.length builtins#get_all) ~env:[] e;
+    check ~print_toplevel ~throw ~level:(List.length builtins#get_all) ~env:[] e;
     if print_toplevel && (T.deref e.t).T.descr <> T.unit then
       add_task (fun () -> Format.printf "@[<2>-     :@ %a@]@." T.pp_type e.t);
-    if ignored && not (can_ignore e.t) then raise (Ignored e);
+    if ignored && not (can_ignore e.t) then throw (Ignored e);
     pop_tasks ()
   with e ->
     pop_tasks ();
