@@ -20,16 +20,19 @@
 
  *****************************************************************************)
 
-let samplerates = [8000;12000;16000;24000;48000]
+let samplerates = [8000; 12000; 16000; 24000; 48000]
 
 let () =
-  ignore (Dtools.Init.at_start (fun () ->
-    let rate = Lazy.force Frame.audio_rate in
-    let rec f = function
-      | [] -> 48000
-      | x :: l when x < rate -> f l
-      | x :: _ -> x
-    in
-    Ogg_demuxer_opus_decoder.decoder_samplerate := f samplerates)); 
+  ignore
+    (Dtools.Init.at_start (fun () ->
+         let rate = Lazy.force Frame.audio_rate in
+         let rec f = function
+           | [] -> 48000
+           | x :: l when x < rate -> f l
+           | x :: _ -> x
+         in
+         Ogg_demuxer_opus_decoder.decoder_samplerate := f samplerates));
   Ogg_demuxer_opus_decoder.register ()
 
+(* Register audio/opus mime *)
+let () = Ogg_decoder.mime_types#set ("audio/opus" :: Ogg_decoder.mime_types#get)
