@@ -25,27 +25,27 @@ let init () =
   Sdl_utils.ttf_init ()
 
 let get_font font size =
-  try
-    Sdlttf.open_font font size
-  with
+  try Sdlttf.open_font font size with
     | Sdlttf.SDLttf_exception s ->
-      raise (Lang_errors.Invalid_value (Lang.string font, s))
+        raise (Lang_errors.Invalid_value (Lang.string font, s))
     | e ->
-      raise (Lang_errors.Invalid_value (Lang.string font, Printexc.to_string e))
+        raise
+          (Lang_errors.Invalid_value (Lang.string font, Printexc.to_string e))
 
 let render_text ~font ~size text =
   let text = if text = "" then " " else text in
   let font = get_font font size in
-  let ts = Sdlttf.render_utf8_shaded font text ~bg:Sdlvideo.black ~fg:Sdlvideo.white in
+  let ts =
+    Sdlttf.render_utf8_shaded font text ~bg:Sdlvideo.black ~fg:Sdlvideo.white
+  in
   let w, h =
     let si = Sdlvideo.surface_info ts in
-    si.Sdlvideo.w, si.Sdlvideo.h
+    (si.Sdlvideo.w, si.Sdlvideo.h)
   in
   let get_pixel x y =
     let r, _, _ = Sdlvideo.get_pixel_color ts ~x ~y in
     r
   in
-  w, h, get_pixel
+  (w, h, get_pixel)
 
-let () =
-  Video_text.register "sdl" init render_text
+let () = Video_text.register "sdl" init render_text
