@@ -19,59 +19,57 @@
 
  *****************************************************************************)
 
-
 class output ~kind ~infallible ~autostart ~on_start ~on_stop source =
-  let video_width    = Lazy.force Frame.video_width in
-  let video_height   = Lazy.force Frame.video_height in
-object
-  inherit Output.output ~name:"graphics" ~output_kind:"output.graphics"
-            ~infallible ~on_start ~on_stop ~content_kind:kind source autostart
+  let video_width = Lazy.force Frame.video_width in
+  let video_height = Lazy.force Frame.video_height in
+  object
+    inherit
+      Output.output
+        ~name:"graphics" ~output_kind:"output.graphics" ~infallible ~on_start
+          ~on_stop ~content_kind:kind source autostart
 
-  val mutable sleep = false
-  method output_stop =
-    sleep <- true
+    val mutable sleep = false
 
-  method output_start =
-    Graphics.open_graph "";
-    Graphics.set_window_title "Liquidsoap";
-    Graphics.resize_window video_width video_height;
-    sleep <- false
+    method output_stop = sleep <- true
 
-  method output_send buf =
-    let rgb =
-      let stop,c = Frame.content buf 0 in
-        assert (stop = Lazy.force Frame.size) ;
+    method output_start =
+      Graphics.open_graph "";
+      Graphics.set_window_title "Liquidsoap";
+      Graphics.resize_window video_width video_height;
+      sleep <- false
+
+    method output_send buf =
+      let rgb =
+        let stop, c = Frame.content buf 0 in
+        assert (stop = Lazy.force Frame.size);
         c.Frame.video.(0)
-    in
+      in
       for frame = 0 to 0 do
         let img = Image.RGBA32.to_int_image rgb.(frame) in
         let img = Graphics.make_image img in
-          Graphics.draw_image img 0 0
+        Graphics.draw_image img 0 0
       done
 
-  method output_reset = ()
-end
+    method output_reset = ()
+  end
 
 let () =
   let k = Lang.kind_type_of_kind_format ~fresh:1 Lang.video_only in
   Lang.add_operator "output.graphics" ~active:true
-    (Output.proto @ [
-      "", Lang.source_t k, None, None
-    ])
-    ~kind:(Lang.Unconstrained k)
-    ~category:Lang.Output
+    (Output.proto @ [("", Lang.source_t k, None, None)])
+    ~kind:(Lang.Unconstrained k) ~category:Lang.Output
     ~descr:"Display video stream using the Graphics library."
     (fun p kind ->
-       let autostart = Lang.to_bool (List.assoc "start" p) in
-       let infallible = not (Lang.to_bool (List.assoc "fallible" p)) in
-       let on_start =
-         let f = List.assoc "on_start" p in
-           fun () -> ignore (Lang.apply ~t:Lang.unit_t f [])
-       in
-       let on_stop =
-         let f = List.assoc "on_stop" p in
-           fun () -> ignore (Lang.apply ~t:Lang.unit_t f [])
-       in
-       let source = List.assoc "" p in
-         ((new output ~kind ~infallible ~autostart ~on_start ~on_stop source)
-            :>Source.source))
+      let autostart = Lang.to_bool (List.assoc "start" p) in
+      let infallible = not (Lang.to_bool (List.assoc "fallible" p)) in
+      let on_start =
+        let f = List.assoc "on_start" p in
+        fun () -> ignore (Lang.apply ~t:Lang.unit_t f [])
+      in
+      let on_stop =
+        let f = List.assoc "on_stop" p in
+        fun () -> ignore (Lang.apply ~t:Lang.unit_t f [])
+      in
+      let source = List.assoc "" p in
+      ( new output ~kind ~infallible ~autostart ~on_start ~on_stop source
+        :> Source.source ))
