@@ -20,33 +20,36 @@
 
  *****************************************************************************)
 
-let log = Log.make ["playlist";"xml"]
+let log = Log.make ["playlist"; "xml"]
 
 let conf_xml =
-  Dtools.Conf.list ~p:(Playlist_parser.conf_mime_types#plug "xml")
-    ~d:["video/x-ms-asf";
+  Dtools.Conf.list
+    ~p:(Playlist_parser.conf_mime_types#plug "xml")
+    ~d:
+      [
+        "video/x-ms-asf";
         "audio/x-ms-asx";
         "text/xml";
         "application/xml";
         "application/smil";
         "application/smil+xml";
         "application/xspf+xml";
-        "application/rss+xml"]
+        "application/rss+xml";
+      ]
     "Mime types associated to XML-based playlist formats"
 
-let tracks ?pwd s = 
-  try 
-    let recode_metas m = 
+let tracks ?pwd s =
+  try
+    let recode_metas m =
       let f = Configure.recode_tag in
-      List.map (fun (a,b) -> (f a,f b)) m
+      List.map (fun (a, b) -> (f a, f b)) m
     in
-    List.map 
-      (fun (a,b) -> recode_metas a, Playlist_parser.get_file ?pwd b) 
+    List.map
+      (fun (a, b) -> (recode_metas a, Playlist_parser.get_file ?pwd b))
       (Xmlplaylist.tracks s)
-  with
-    | Xmlplaylist.Error(e) -> log#debug "Parsing failed: %s" 
-                                 (Xmlplaylist.string_of_error e) ;
-		              raise (Xmlplaylist.Error(e))
+  with Xmlplaylist.Error e ->
+    log#debug "Parsing failed: %s" (Xmlplaylist.string_of_error e);
+    raise (Xmlplaylist.Error e)
 
 let register mimetype =
   Playlist_parser.parsers#register mimetype
