@@ -36,7 +36,12 @@ let log = Log.make ["request"]
 
 (** File utilities. *)
 
-let remove_file_proto s = Pcre.substitute ~pat:"^file://" ~subst:(fun _ -> "") s
+let remove_file_proto s =
+  (* First remove file:// 🤮 *)
+  let s = Pcre.substitute ~pat:"^file://" ~subst:(fun _ -> "") s in
+  (* Then remove file: 😇 *)
+  Pcre.substitute ~pat:"^file:" ~subst:(fun _ -> "") s
+
 let home_unrelate s = Utils.home_unrelate (remove_file_proto s)
 
 let parse_uri uri =
