@@ -27,44 +27,53 @@ open Source
 class gen ~kind ~seek name g freq duration ampl =
   let channels = (Frame.type_of_kind kind).Frame.audio in
   let g = g freq ampl in
-object
-  inherit Synthesized.source ~seek ~name kind duration
+  object
+    inherit Synthesized.source ~seek ~name kind duration
 
-  method private synthesize frame off len =
-    let off = Frame.audio_of_master off in
-    let len = Frame.audio_of_master len in
-    let buf = AFrame.content_of_type ~channels frame off in
-    g#fill buf off len
-end
+    method private synthesize frame off len =
+      let off = Frame.audio_of_master off in
+      let len = Frame.audio_of_master len in
+      let buf = AFrame.content_of_type ~channels frame off in
+      g#fill buf off len
+  end
 
 let add name g =
-  Lang.add_operator name
-    ~category:Lang.Input
+  Lang.add_operator name ~category:Lang.Input
     ~descr:("Generate a " ^ name ^ " wave.")
     ~kind:Lang.audio_any
     [
-      "duration", Lang.float_t, Some (Lang.float 0.), Some "Duration in seconds (0. means infinite).";
-      "amplitude", Lang.float_t, Some (Lang.float 1.), Some "Maximal value of the waveform.";
-      "", Lang.float_t, Some (Lang.float 440.), Some ("Frequency of the " ^ name ^ ".")
+      ( "duration",
+        Lang.float_t,
+        Some (Lang.float 0.),
+        Some "Duration in seconds (0. means infinite)." );
+      ( "amplitude",
+        Lang.float_t,
+        Some (Lang.float 1.),
+        Some "Maximal value of the waveform." );
+      ( "",
+        Lang.float_t,
+        Some (Lang.float 440.),
+        Some ("Frequency of the " ^ name ^ ".") );
     ]
     (fun p kind ->
-      (new gen ~seek:true ~kind name g
-         (Lang.to_float (List.assoc "" p))
-         (Lang.to_float (List.assoc "duration" p))
-         (Lang.to_float (List.assoc "amplitude" p)) :> source))
+      ( new gen
+          ~seek:true ~kind name g
+          (Lang.to_float (List.assoc "" p))
+          (Lang.to_float (List.assoc "duration" p))
+          (Lang.to_float (List.assoc "amplitude" p))
+        :> source ))
 
 let sine f volume =
-   new Audio.Generator.of_mono
-         (new Audio.Mono.Generator.sine
-             (Lazy.force Frame.audio_rate) ~volume f)
+  new Audio.Generator.of_mono
+    (new Audio.Mono.Generator.sine (Lazy.force Frame.audio_rate) ~volume f)
+
 let square f volume =
-   new Audio.Generator.of_mono
-         (new Audio.Mono.Generator.square
-           (Lazy.force Frame.audio_rate) ~volume f)
+  new Audio.Generator.of_mono
+    (new Audio.Mono.Generator.square (Lazy.force Frame.audio_rate) ~volume f)
+
 let saw f volume =
-   new Audio.Generator.of_mono
-         (new Audio.Mono.Generator.saw
-            (Lazy.force Frame.audio_rate) ~volume f)
+  new Audio.Generator.of_mono
+    (new Audio.Mono.Generator.saw (Lazy.force Frame.audio_rate) ~volume f)
 
 let () =
   add "sine" sine;
