@@ -25,10 +25,11 @@ open Frame
 type t = Frame.t
 
 let tov = Frame.master_of_video
+
 let vot ?round x =
- match round with
-   | None | Some `Down -> Frame.video_of_master x
-   | Some `Up -> Frame.video_of_master (x + Lazy.force Frame.video_rate - 1)
+  match round with
+    | None | Some `Down -> Frame.video_of_master x
+    | Some `Up -> Frame.video_of_master (x + Lazy.force Frame.video_rate - 1)
 
 let size _ = vot (Lazy.force size)
 let next_sample_position t = vot ~round:`Up (Frame.position t)
@@ -38,17 +39,19 @@ let position t = vot (position t)
 
 let get_content frame source =
   let p0 = Frame.position frame in
-  let p1 = source#get frame ; Frame.position frame in
+  let p1 =
+    source#get frame;
+    Frame.position frame
+  in
   let v0 = vot ~round:`Up p0 in
   let v1 = vot ~round:`Down p1 in
-    if v0<v1 then
-      let stop,content = Frame.content frame p0 in
-        assert (stop = Lazy.force Frame.size) ;
-        Some (content.video,v0,v1-v0)
-    else
-      None
+  if v0 < v1 then (
+    let stop, content = Frame.content frame p0 in
+    assert (stop = Lazy.force Frame.size);
+    Some (content.video, v0, v1 - v0) )
+  else None
 
 let content_of_type ~channels b =
-  let ctype = { audio = 0 ; video = channels ; midi = 0 } in
+  let ctype = { audio = 0; video = channels; midi = 0 } in
   let content = content_of_type b (Frame.position b) ctype in
-    content.video
+  content.video
