@@ -27,16 +27,20 @@ let ogg_video_mime = "video/ogg"
 let wav_mime = "audio/wav"
 let avi_mime = "video/avi"
 let aac_mime = "audio/aac"
-let flac_mime = "audio/x-flac"
+let flac_mime = "audio/flac"
 
-let base_proto kind = 
-    ["format", Lang.string_t, Some (Lang.string ""),
-      Some "Format, e.g. \"audio/ogg\". \
-      When empty, the encoder is used to guess." ;
-     "", Lang.format_t kind, None, Some "Encoding format."]
+let base_proto kind =
+  [
+    ( "format",
+      Lang.string_t,
+      Some (Lang.string ""),
+      Some
+        "Format, e.g. \"audio/ogg\". When empty, the encoder is used to guess."
+    );
+    ("", Lang.format_t kind, None, Some "Encoding format.");
+  ]
 
-module type Icecast_t =
-sig
+module type Icecast_t = sig
   type content
 
   val format_of_content : string -> content
@@ -46,12 +50,11 @@ sig
   val info_of_encoder : Encoder.format -> info
 end
 
-module Icecast_v(M:Icecast_t) = 
-struct
+module Icecast_v (M : Icecast_t) = struct
   type encoder_data = {
     factory : string -> Meta_format.export_metadata -> Encoder.encoder;
-    format  : M.content;
-    info    : M.info;
+    format : M.content;
+    info : M.info;
   }
 
   let mpeg = M.format_of_content mpeg_mime
@@ -64,42 +67,39 @@ struct
   let aac = M.format_of_content aac_mime
   let flac = M.format_of_content flac_mime
 
-  let format_of_encoder =
-    function
-      | Encoder.MP3 _ -> Some mpeg
-      | Encoder.Shine _ -> Some mpeg
-      | Encoder.Ffmpeg _ -> None
-      | Encoder.FdkAacEnc _ -> Some aac
-      | Encoder.External _ -> None
-      | Encoder.GStreamer _ -> None
-      | Encoder.Flac _ -> Some flac
-      | Encoder.WAV _ -> Some wav
-      | Encoder.AVI _ -> Some avi
-      | Encoder.Ogg _ -> Some ogg
+  let format_of_encoder = function
+    | Encoder.MP3 _ -> Some mpeg
+    | Encoder.Shine _ -> Some mpeg
+    | Encoder.Ffmpeg _ -> None
+    | Encoder.FdkAacEnc _ -> Some aac
+    | Encoder.External _ -> None
+    | Encoder.GStreamer _ -> None
+    | Encoder.Flac _ -> Some flac
+    | Encoder.WAV _ -> Some wav
+    | Encoder.AVI _ -> Some avi
+    | Encoder.Ogg _ -> Some ogg
 
   let encoder_data p =
     let v = Lang.assoc "" 1 p in
     let enc = Lang.to_format v in
-    let info,format =
-       M.info_of_encoder enc,format_of_encoder enc
-    in
+    let info, format = (M.info_of_encoder enc, format_of_encoder enc) in
     let encoder_factory =
-      try Encoder.get_factory enc with
-        | Not_found ->
-            raise (Lang_errors.Invalid_value
-                     (v, "No encoder found for that format"))
+      try Encoder.get_factory enc
+      with Not_found ->
+        raise
+          (Lang_errors.Invalid_value (v, "No encoder found for that format"))
     in
     let format =
       let f = Lang.to_string (List.assoc "format" p) in
-        if f <> "" then M.format_of_content f else
-          match format with
-            | Some x -> x
-            | None   -> raise (Lang_errors.Invalid_value (Lang.assoc "" 1 p,
-                                                 "No format (mime) found, \
-                                                  please specify one."))
+      if f <> "" then M.format_of_content f
+      else (
+        match format with
+          | Some x -> x
+          | None ->
+              raise
+                (Lang_errors.Invalid_value
+                   ( Lang.assoc "" 1 p,
+                     "No format (mime) found, please specify one." )) )
     in
-    { factory = encoder_factory;
-      format  = format;
-      info    = info }
+    { factory = encoder_factory; format; info }
 end
-
