@@ -23,16 +23,15 @@
 (** Manage an unbounded pool of objects identified by integers.
   * This is used for Requests. *)
 
-module type T =
-sig
+module type T = sig
   (** Type of objects stored in the pool. *)
   type t
 end
 
-module type S =
-sig
+module type S = sig
   type t
-  val add  : unit -> int * (t -> unit)
+
+  val add : unit -> int * (t -> unit)
   val kill : int -> float -> unit
   val find : int -> t option
   val fold : (int -> t -> 'a -> 'a) -> 'a -> 'a
@@ -41,62 +40,48 @@ sig
   val size : unit -> int
 end
 
-module Make (P:T) : (S with type t = P.t) =
-struct
-
+module Make (P : T) : S with type t = P.t = struct
   type t = P.t
-
-  type entry = {
-    death_time : float option ;
-    value : t option
-  }
+  type entry = { death_time : float option; value : t option }
 
   let m = Mutex.create ()
-  let h : (int,entry) Hashtbl.t = Hashtbl.create 100
-
-  let size =
-    Tutils.mutexify m (fun () -> Hashtbl.length h)
+  let h : (int, entry) Hashtbl.t = Hashtbl.create 100
+  let size = Tutils.mutexify m (fun () -> Hashtbl.length h)
 
   let find =
-    Tutils.mutexify m
-      (fun i ->
-         try (Hashtbl.find h i).value with
-           | Not_found -> None)
+    Tutils.mutexify m (fun i ->
+        try (Hashtbl.find h i).value with Not_found -> None)
 
   let fold f x =
     Tutils.mutexify m
       (fun f x ->
-         Hashtbl.fold
-           (fun i entry x ->
-              match entry.value with
-                | Some t -> f i t x
-                | None -> x)
-           h x)
+        Hashtbl.fold
+          (fun i entry x ->
+            match entry.value with Some t -> f i t x | None -> x)
+          h x)
       f x
 
   let iter f =
     Tutils.mutexify m
       (fun f ->
-         Hashtbl.iter
-           (fun i entry ->
-              match entry.value with
-                | Some t ->
-                    Mutex.unlock m ;
-                    f i t ;
-                    Mutex.lock m
-                | None -> ())
-           h)
+        Hashtbl.iter
+          (fun i entry ->
+            match entry.value with
+              | Some t ->
+                  Mutex.unlock m;
+                  f i t;
+                  Mutex.lock m
+              | None -> ())
+          h)
       f
 
-  let remove i =
-    Hashtbl.remove h i
+  let remove i = Hashtbl.remove h i
 
   let kill i grace =
     Tutils.mutexify m
       (fun () ->
-         Hashtbl.replace h i
-           { (Hashtbl.find h i) with
-                death_time = Some (Unix.time () +. grace) })
+        Hashtbl.replace h i
+          { (Hashtbl.find h i) with death_time = Some (Unix.time () +. grace) })
       ()
 
   let next =
@@ -104,20 +89,17 @@ struct
       try
         match (Hashtbl.find h i).death_time with
           | Some t when Unix.time () > t -> i
-          | _ -> find (i+1)
-      with
-        | Not_found -> i
+          | _ -> find (i + 1)
+      with Not_found -> i
     in
-      Tutils.mutexify m
-        (fun () ->
-           let i = find 0 in
-             Hashtbl.replace h i { death_time = None ; value = None } ;
-             i)
+    Tutils.mutexify m (fun () ->
+        let i = find 0 in
+        Hashtbl.replace h i { death_time = None; value = None };
+        i)
 
   let add () =
     let i = next () in
-      i,
-      Tutils.mutexify m
-        (fun t -> Hashtbl.replace h i { death_time = None ; value = Some t })
-
+    ( i,
+      Tutils.mutexify m (fun t ->
+          Hashtbl.replace h i { death_time = None; value = Some t }) )
 end
