@@ -48,34 +48,33 @@ module Int32 = struct
     let mask = shift_left one 31 in
     fun n -> logand n mask <> zero
 
-  let leftrotate n k =
-    logor (shift_left n k) (shift_right_logical n (32 - k))
+  let leftrotate n k = logor (shift_left n k) (shift_right_logical n (32 - k))
 end
 
 (** Digest a string using SHA-1. *)
 let digest s =
   (* Pad string and append length. *)
   let len = String.length s in
-  let s = s ^ (String.make 1 (char_of_int 0b10000000)) in
-  let pad = 64 - ((len+1) mod 64) - 8 in
+  let s = s ^ String.make 1 (char_of_int 0b10000000) in
+  let pad = 64 - ((len + 1) mod 64) - 8 in
   let pad = if pad < 0 then pad + 64 else pad in
   let pad = String.make pad (char_of_int 0) in
   let slen =
     let ans = Bytes.create 8 in
-    let len = ref (8*len) in
+    let len = ref (8 * len) in
     for i = 7 downto 0 do
       Bytes.set ans i (char_of_int (!len land 0xff));
-      len := !len lsr 8;
+      len := !len lsr 8
     done;
     Bytes.unsafe_to_string ans
   in
   let s = s ^ pad ^ slen in
 
   let lnot = Int32.lognot in
-  let (land) = Int32.logand in
-  let (lor) = Int32.logor in
-  let (lxor) = Int32.logxor in
-  let (++) = Int32.add in
+  let ( land ) = Int32.logand in
+  let ( lor ) = Int32.logor in
+  let ( lxor ) = Int32.logxor in
+  let ( ++ ) = Int32.add in
 
   (* Main loop. *)
   let len = String.length s in
@@ -86,15 +85,18 @@ let digest s =
   let h3 = ref 0x10325476l in
   let h4 = ref 0xC3D2E1F0l in
 
-  for chunk = 0 to len / 64 - 1 do
+  for chunk = 0 to (len / 64) - 1 do
     (* Extend words. *)
     let w = Array.make 80 Int32.zero in
     for i = 0 to 15 do
-      let off = 64 * chunk + 4 * i in
+      let off = (64 * chunk) + (4 * i) in
       w.(i) <- Int32.of_string_be s off
     done;
     for i = 16 to 79 do
-      w.(i) <- Int32.leftrotate (w.(i-3) lxor w.(i-8) lxor w.(i-14) lxor w.(i-16)) 1
+      w.(i) <-
+        Int32.leftrotate
+          (w.(i - 3) lxor w.(i - 8) lxor w.(i - 14) lxor w.(i - 16))
+          1
     done;
 
     (* Main loop. *)
@@ -106,9 +108,9 @@ let digest s =
 
     for i = 0 to 79 do
       let f =
-        if i <= 19 then (!b land !c) lor ((lnot !b) land !d)
+        if i <= 19 then !b land !c lor (lnot !b land !d)
         else if i <= 39 then !b lxor !c lxor !d
-        else if i <= 59 then (!b land !c) lor (!b land !d) lor (!c land !d)
+        else if i <= 59 then !b land !c lor (!b land !d) lor (!c land !d)
         else !b lxor !c lxor !d
       in
       let k =
@@ -117,12 +119,12 @@ let digest s =
         else if i <= 59 then 0x8F1BBCDCl
         else 0xCA62C1D6l
       in
-      let temp = (Int32.leftrotate !a 5) ++ f ++ !e ++ k ++ w.(i) in
+      let temp = Int32.leftrotate !a 5 ++ f ++ !e ++ k ++ w.(i) in
       e := !d;
       d := !c;
       c := Int32.leftrotate !b 30;
       b := !a;
-      a := temp;
+      a := temp
     done;
 
     h0 := Int32.add !h0 !a;
@@ -132,9 +134,10 @@ let digest s =
     h4 := Int32.add !h4 !e
   done;
   (* Printf.sprintf "%s %s %s %s %s" (Int32.String.hexadecimal !h0) (Int32.String.hexadecimal !h1) (Int32.String.hexadecimal !h2) (Int32.String.hexadecimal !h3) (Int32.String.hexadecimal !h4) *)
-  Int32.to_string_be !h0 ^ Int32.to_string_be !h1 ^ Int32.to_string_be !h2 ^ Int32.to_string_be !h3 ^ Int32.to_string_be !h4
+  Int32.to_string_be !h0 ^ Int32.to_string_be !h1 ^ Int32.to_string_be !h2
+  ^ Int32.to_string_be !h3 ^ Int32.to_string_be !h4
 
 (* let () = *)
-  (* (\* Example from Wikipedia page *\) *)
-  (* let s = "The quick brown fox jumps over the lazy dog" in *)
-  (* assert (digest s = "\x2f\xd4\xe1\xc6\x7a\x2d\x28\xfc\xed\x84\x9e\xe1\xbb\x76\xe7\x39\x1b\x93\xeb\x12") *)
+(* (\* Example from Wikipedia page *\) *)
+(* let s = "The quick brown fox jumps over the lazy dog" in *)
+(* assert (digest s = "\x2f\xd4\xe1\xc6\x7a\x2d\x28\xfc\xed\x84\x9e\xe1\xbb\x76\xe7\x39\x1b\x93\xeb\x12") *)
